@@ -73,8 +73,17 @@ use strict;
 no warnings "uninitialized";
 
 use Carp;
-our $DIEHOOK  = sub { };
-our $WARNHOOK = sub { warn $_[0] };
+
+our $DIEHOOK;
+our $WARNHOOK;
+
+BEGIN {
+   $DIEHOOK  = sub { };
+   $WARNHOOK = sub { warn $_[0] };
+}
+
+sub diehook  { &$DIEHOOK  }
+sub warnhook { &$WARNHOOK }
 
 use XSLoader;
 
@@ -85,6 +94,9 @@ BEGIN {
    # it might exist already because Coro::Specific created it.
    $Coro::current ||= { };
 
+   $SIG{__DIE__}  = \&diehook;
+   $SIG{__WARN__} = \&warnhook;
+
    XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -160,8 +172,7 @@ and have the stated initial values:
    (default fh)   *STDOUT
    $1, $2...      all regex results are initially undefined
 
-   (*) may not read back properly, for speed reasons, but
-       local()ising should be safe.
+   (*) reading the value from %SIG is not supported, but local'ising is.
 
 If you feel that something important is missing then tell me. Also
 remember that every function call that might call C<transfer> (such
